pub struct RayMap {
pub map: HashMap<RayId, Ray3d>,
}Expand description
This map is cleared and re-populated every frame before any backends run. Ray-based picking backends should use this when possible, as it automatically handles viewports, DPI, and other details of building rays from pointer locations.
Usage
Iterate over each Ray3d and its RayId with RayMap::iter.
// My raycasting backend
pub fn update_hits(ray_map: Res<RayMap>, mut output_messages: MessageWriter<PointerHits>,) {
for (&ray_id, &ray) in ray_map.iter() {
// Run a raycast with each ray, returning any `PointerHits` found.
}
}Fields
map: HashMap<RayId, Ray3d>Cartesian product of all pointers and all cameras Add your rays here to support picking through indirections, e.g. rendered-to-texture cameras
Implementations
Sourceimpl RayMap
impl RayMap
Sourcepub fn iter(&self) -> Iter<'_, RayId, Ray3d>
pub fn iter(&self) -> Iter<'_, RayId, Ray3d>
Iterates over all world space rays for every picking pointer.
Sourcepub fn repopulate(
ray_map: ResMut<'_, Self>,
primary_window_entity: Query<'_, '_, Entity, With<PrimaryWindow>>,
cameras: Query<'_, '_, (Entity, &Camera, &RenderTarget, &GlobalTransform)>,
pointers: Query<'_, '_, (&PointerId, &PointerLocation)>,
)
pub fn repopulate( ray_map: ResMut<'_, Self>, primary_window_entity: Query<'_, '_, Entity, With<PrimaryWindow>>, cameras: Query<'_, '_, (Entity, &Camera, &RenderTarget, &GlobalTransform)>, pointers: Query<'_, '_, (&PointerId, &PointerLocation)>, )
Clears the RayMap and re-populates it with one ray for each
combination of pointer entity and camera entity where the pointer
intersects the camera’s viewport.